@@ -3,11 +3,12 @@
 if [ x$1 = x ] ; then
 LG=fr
 else
-LG=$1
+LG=`basename $1 .po`
 fi
 
 cd `dirname $0`
 
+echo "generation of $LG.mo from $LG.po... "
 xgettext --keyword="_" --keyword="translate"  ../bins
 #xpot --keyword="_" --keyword="translate" ../bins >messages.po 
 touch $LG.po
